# coding: utf-8

"""
    SENSE-O Northbound Intent API

    StackV SENSE-O Northbound REST API Documentation  # noqa: E501

    OpenAPI spec version: 2.0.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DNCSchemaData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'uuid': 'str',
        'type': 'str',
        'connections': 'list[Connection]'
    }

    attribute_map = {
        'uuid': 'uuid',
        'type': 'type',
        'connections': 'connections'
    }

    def __init__(self, uuid=None, type='Multi-Point L3VPN', connections=None):  # noqa: E501
        """DNCSchemaData - a model defined in Swagger"""  # noqa: E501
        self._uuid = None
        self._type = None
        self._connections = None
        self.discriminator = None
        if uuid is not None:
            self.uuid = uuid
        self.type = type
        self.connections = connections

    @property
    def uuid(self):
        """Gets the uuid of this DNCSchemaData.  # noqa: E501

        Optional reference to instance UUID.  # noqa: E501

        :return: The uuid of this DNCSchemaData.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this DNCSchemaData.

        Optional reference to instance UUID.  # noqa: E501

        :param uuid: The uuid of this DNCSchemaData.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def type(self):
        """Gets the type of this DNCSchemaData.  # noqa: E501

        DNC configuration mode.  # noqa: E501

        :return: The type of this DNCSchemaData.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DNCSchemaData.

        DNC configuration mode.  # noqa: E501

        :param type: The type of this DNCSchemaData.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["Multi-Path P2P VLAN", "Multi-Point VLAN Bridge", "Multi-Point L3VPN"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def connections(self):
        """Gets the connections of this DNCSchemaData.  # noqa: E501

        The array of service connections.  # noqa: E501

        :return: The connections of this DNCSchemaData.  # noqa: E501
        :rtype: list[Connection]
        """
        return self._connections

    @connections.setter
    def connections(self, connections):
        """Sets the connections of this DNCSchemaData.

        The array of service connections.  # noqa: E501

        :param connections: The connections of this DNCSchemaData.  # noqa: E501
        :type: list[Connection]
        """
        if connections is None:
            raise ValueError("Invalid value for `connections`, must not be `None`")  # noqa: E501

        self._connections = connections

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DNCSchemaData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DNCSchemaData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
